RoomServiceBase class abstract

Annotations
  • @GrpcServiceName.new('services.tasks_svc.v1.RoomService')

Constructors

RoomServiceBase()

Properties

$name String
no setter
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

$addMethod(ServiceMethod method) → void
inherited
$lookupMethod(String name) → ServiceMethod?
inherited
$onMetadata(ServiceCall context) → void
Client metadata handler.
inherited
createRoom(ServiceCall call, CreateRoomRequest request) Future<CreateRoomResponse>
createRoom_Pre(ServiceCall call, Future<CreateRoomRequest> request) Future<CreateRoomResponse>
deleteRoom(ServiceCall call, DeleteRoomRequest request) Future<DeleteRoomResponse>
deleteRoom_Pre(ServiceCall call, Future<DeleteRoomRequest> request) Future<DeleteRoomResponse>
getRoom(ServiceCall call, GetRoomRequest request) Future<GetRoomResponse>
getRoom_Pre(ServiceCall call, Future<GetRoomRequest> request) Future<GetRoomResponse>
getRoomOverviewsByWard(ServiceCall call, GetRoomOverviewsByWardRequest request) Future<GetRoomOverviewsByWardResponse>
getRoomOverviewsByWard_Pre(ServiceCall call, Future<GetRoomOverviewsByWardRequest> request) Future<GetRoomOverviewsByWardResponse>
getRooms(ServiceCall call, GetRoomsRequest request) Future<GetRoomsResponse>
getRooms_Pre(ServiceCall call, Future<GetRoomsRequest> request) Future<GetRoomsResponse>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
updateRoom(ServiceCall call, UpdateRoomRequest request) Future<UpdateRoomResponse>
updateRoom_Pre(ServiceCall call, Future<UpdateRoomRequest> request) Future<UpdateRoomResponse>

Operators

operator ==(Object other) bool
The equality operator.
inherited